@@ -21,20 +21,27 @@
 #ifndef KWALLETEDITOR_H
 #define KWALLETEDITOR_H
 
-#include "walletwidget.h"
+#include "ui_walletwidget.h"
 #include <kwallet.h>
-#include <kmainwindow.h>
-#include <qstringlist.h>
+#include <kxmlguiwindow.h>
+#include <QStringList>
+#include <QLabel>
 
-class KAction;
-class QIconViewItem;
-class QListViewItem;
+class Q3ListViewItem;
 class QCheckBox;
-class KWalletFolderIconView;
 class KWalletEntryList;
 class KWMapEditor;
+class KAction;
+class WalletWidget : public QWidget, public Ui::WalletWidget
+{
+public:
+  WalletWidget( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
 
-class KWalletEditor : public KMainWindow {
+
+class KWalletEditor : public KXmlGuiWindow {
 	Q_OBJECT
 
 	public:
@@ -53,9 +60,9 @@ class KWalletEditor : public KMainWindow {
 	private slots:
 		void layout();
 		void updateFolderList(bool checkEntries = false);
-		void entrySelectionChanged(QListViewItem *item);
-		void listItemRenamed(QListViewItem *, int, const QString&);
-		void listContextMenuRequested(QListViewItem *item, const QPoint& pos, int col);
+		void entrySelectionChanged(Q3ListViewItem *item);
+		void listItemRenamed(Q3ListViewItem *, int, const QString&);
+		void listContextMenuRequested(Q3ListViewItem *item, const QPoint& pos, int col);
 		void updateEntries(const QString& folder);
 
 		void newEntry();
@@ -83,7 +90,7 @@ class KWalletEditor : public KMainWindow {
 		void enableWalletActions(bool enable);
 		void enableFolderActions(bool enable);
 		void enableContextFolderActions(bool enable);
-		void editorClosed(KMainWindow*);
+		void editorClosed(KXmlGuiWindow*);
 
 	public:
 		QString _walletName;
@@ -95,9 +102,10 @@ class KWalletEditor : public KMainWindow {
 		WalletWidget *_ww;
 		KWalletEntryList *_entryList;
 		bool _walletIsOpen;
-		KAction *_newFolderAction, *_deleteFolderAction;
-		KAction *_passwordAction, *_exportAction, *_saveAsAction, *_mergeAction, *_importAction;
-		KAction *_copyPassAction;
+		QAction *_newFolderAction, *_deleteFolderAction;
+		QAction *_passwordAction, *_exportAction, *_saveAsAction, *_mergeAction, *_importAction;
+		KAction *_newEntryAction, *_renameEntryAction, *_deleteEntryAction;
+		QAction *_copyPassAction;
 		QLabel*_details;
 		QString _currentFolder;
 		QMap<QString,QString> _currentMap; // save memory by storing
@@ -105,6 +113,7 @@ class KWalletEditor : public KMainWindow {
 		KWMapEditor *_mapEditor;
 		QCheckBox *_mapEditorShowHide;
 		bool _newWallet;
+		KMenu *_contextMenu;
 };
 
 #endif
